@@ -6,7 +6,7 @@
 ;; Maintainer: Protesilaos Stavrou General Issues <~protesilaos/general-issues@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/beframe
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/general-issues
-;; Version: 0.1.10
+;; Version: 0.1.11
 ;; Package-Requires: ((emacs "28.1"))
 
 ;; This file is NOT part of GNU Emacs.
@@ -410,6 +410,9 @@ Also see `beframe-assume-frame-buffers'."
 (defalias 'beframe-remove-frame-buffers 'beframe-unassume-frame-buffers
   "Alias of `beframe-unassume-frame-buffers' command.")
 
+;; TODO 2023-03-02: Define commands to `completing-read-multiple'
+;; assume/unassume buffers.
+
 ;;; Minor mode setup
 
 (defvar beframe--read-buffer-function nil
@@ -426,7 +429,8 @@ Also see `beframe-assume-frame-buffers'."
         (add-hook 'after-make-frame-functions #'beframe--frame-predicate)
         (when beframe-rename-function
           (add-hook 'after-make-frame-functions beframe-rename-function))
-        (add-hook 'after-make-frame-functions #'beframe-create-scratch-buffer)
+        (when beframe-create-frame-scratch-buffer
+          (add-hook 'after-make-frame-functions #'beframe-create-scratch-buffer))
         (beframe--functions-in-frames))
     (setq read-buffer-function beframe--read-buffer-function
           beframe--read-buffer-function nil)
